function commonSubmitArgs = getCommonSubmitArgs(cluster, numWorkers)
% Get any additional submit arguments for the Slurm sbatch command
% that are common to both independent and communicating jobs.

% Copyright 2016-2019 The MathWorks, Inc.

% https://www.glue.umd.edu/hpcc/help/jobs.html

% MW: Not supported
%     1. --tmp=
%     2. --workingdir=
%     3. -N
%     4. --mem=

% MW: Need to ensure IB support is working

% MW: Need to fix mpiexec error
%     https://www.mathworks.com/support/bugreports/1997976#

commonSubmitArgs = '';

% Number of cores/node
ppn = validatedPropValue(cluster, 'ProcsPerNode', 'double');
if ppn>0
    % Don't request more cores/node than workers
    ppn = min(numWorkers,ppn);
    commonSubmitArgs = sprintf('%s --ntasks-per-node=%d',commonSubmitArgs,ppn);
end
commonSubmitArgs = sprintf('%s --ntasks-per-core=1',commonSubmitArgs);


%% REQUIRED

% Walltime
wt = validatedPropValue(cluster, 'WallTime', 'char');
if isempty(wt)
    emsg = sprintf(['\n\t>> %% Must set WallTime.  E.g.\n\n', ...
                    '\t>> c = parcluster;\n', ...
                    '\t>> %% 5 hours\n', ...
                    '\t>> c.AdditionalProperties.WallTime = ''05:00:00'';\n', ...
                    '\t>> c.saveProfile\n\n']);
    error(emsg) %#ok<SPERR>
else
    commonSubmitArgs = [commonSubmitArgs ' -t ' wt];
end


%% OPTIONAL

% AccountName
an = validatedPropValue(cluster, 'AccountName', 'char');
if ~isempty(an)
    commonSubmitArgs = [commonSubmitArgs ' -A ' an];
end

% Partition
qn = validatedPropValue(cluster, 'QueueName', 'char');
if ~isempty(qn)
    commonSubmitArgs = [commonSubmitArgs ' -p ' qn];
end

% GPU
ngpus = validatedPropValue(cluster, 'GpusPerNode', 'double');
if ngpus>0
    commonSubmitArgs = sprintf('%s --gres=gpu:%d', commonSubmitArgs, ngpus);
end

% Physical Memory used by a single core
mu = validatedPropValue(cluster, 'MemUsage', 'char');
if ~isempty(mu)
    % Per CPU (in MB)
    commonSubmitArgs = [commonSubmitArgs ' --mem-per-cpu=' mu];
end

% Allows for node to be shared
as = validatedPropValue(cluster, 'AllowedShared', 'bool');
if as==true
    commonSubmitArgs = [commonSubmitArgs ' --share'];
end

% Reservation
res = validatedPropValue(cluster, 'Reservation', 'char');
if ~isempty(res)
    commonSubmitArgs = [commonSubmitArgs ' --reservation=' res];
end

% Email notification
ea = validatedPropValue(cluster, 'EmailAddress', 'char');
if ~isempty(ea)
    commonSubmitArgs = [commonSubmitArgs ' --mail-type=ALL --mail-user=' ea];
end

%% CAMPUS-WIDE LICENSE
% Every job is going to require a certain number of MATLAB Parallel Server licenses.
% Specification of  licenses which must be allocated to this job.
%
% The /etc/slurm/slurm.conf file must list:
%
%   # MATLAB Parallel Server licenses
%   Licenses=MATLAB_Distrib_Comp_Engine:100000
%
% And then call
%
%   % scontrol reconfigure
%
%commonSubmitArgs = sprintf('%s --licenses=MATLAB_Distrib_Comp_Engine:%d',commonSubmitArgs,numWorkers);

% Catch-all
asa = validatedPropValue(cluster, 'AdditionalSubmitArgs', 'char');
if ~isempty(asa)
    commonSubmitArgs = [commonSubmitArgs ' ' asa];
end

commonSubmitArgs = strtrim(commonSubmitArgs);
